==> typestyle-0.14.5.tgz: package/lib/index.js <==
"use strict";
var formatting_1 = require("./internal/formatting");
/**
 * @module Maintains a single stylesheet and keeps it in sync with requested styles
 */
var FreeStyle = require("free-style");
/** Raf for node + browser */
var raf = typeof requestAnimationFrame === 'undefined' ? setTimeout : requestAnimationFrame;
/**
 * Only calls cb all sync operations settle
 */
var afterAllSync = (new (function () {
    function class_1() {
        var _this = this;
        this.pending = 0;
        this.afterAllSync = function (cb) {
            _this.pending++;
            var pending = _this.pending;
            raf(function () {
                if (pending !== _this.pending)
                    return;
                cb();
            });
        };
    }
    return class_1;
}())).afterAllSync;
/**
 * We have a single stylesheet that we update as components register themselves
 */
var freeStyle = FreeStyle.create();
var lastFreeStyleChangeId = freeStyle.changeId;
/**
 * We create a tag on first request or return the one that was hydrated
 */
var _a = new (function () {
    function class_2() {
        var _this = this;
        this.singletonTag = undefined;
        this.getTag = function () {
            if (!_this.singletonTag) {
                _this.singletonTag = typeof window === 'undefined' ? { innerHTML: '' } : document.createElement('style');
                if (typeof document !== 'undefined')
                    document.head.appendChild(_this.singletonTag);
            }
            return _this.singletonTag;
        };
        this.setTag = function (tag) {
            /** Clear any data in any previous tag */
            if (_this.singletonTag) {
                _this.singletonTag.innerHTML = '';
            }
            _this.singletonTag = tag;
            /** This special time buffer immediately */
            forceRenderStyles();
        };
    }
    return class_2;
}()), setTag = _a.setTag, getTag = _a.getTag;
/** Sets the target tag where we write the css on style updates */
exports.setStylesTarget = setTag;
/** Checks if the style tag needs updating and if so queues up the change */
var styleUpdated = function () {
    if (freeStyle.changeId === lastFreeStyleChangeId
        && !pendingRawChange)
        return;
    lastFreeStyleChangeId = freeStyle.changeId;
    pendingRawChange = false;
    afterAllSync(forceRenderStyles);
};
var pendingRawChange = false;
var raw = '';
/**
 * Insert `raw` CSS as a string. This is useful for e.g.
 * - third party CSS that you are customizing with template strings
 * - generating raw CSS in JavaScript
 * - reset libraries like normalize.css that you can use without loaders
 */
function cssRaw(mustBeValidCSS) {
    if (!mustBeValidCSS)
        return;
    raw = raw + mustBeValidCSS;
    pendingRawChange = true;
    styleUpdated();
}
exports.cssRaw = cssRaw;
/**
 * Renders styles to the singleton tag imediately
 * NOTE: You should only call it on initial render to prevent any non CSS flash.
 * After that it is kept sync using `requestAnimationFrame` and we haven't noticed any bad flashes.
 **/
function forceRenderStyles() {
    getTag().innerHTML = exports.css();
}
exports.forceRenderStyles = forceRenderStyles;
/**
 * Helps with testing. Reinitializes FreeStyle + raw
 */
function reinit() {
    /** reinit freestyle */
    freeStyle = FreeStyle.create();
    lastFreeStyleChangeId = freeStyle.changeId;
    /** reinit raw */
    raw = '';
    pendingRawChange = false;
    /** Clear any styles that were flushed */
    getTag().innerHTML = '';
}
exports.reinit = reinit;
/**
 * Allows use to use the stylesheet in a node.js environment
 */
exports.css = function () { return raw ? raw + freeStyle.getStyles() : freeStyle.getStyles(); };
/**
 * Takes CSSProperties and return a generated className you can use on your component
 */
function style() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    var _a = formatting_1.ensureStringObj(extend.apply(void 0, objects)), result = _a.result, debugName = _a.debugName;
    var className = debugName ? freeStyle.registerStyle(result, debugName) : freeStyle.registerStyle(result);
    styleUpdated();
    return className;
}
exports.style = style;
function fontFace() {
    var fontFace = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        fontFace[_i] = arguments[_i];
    }
    for (var _a = 0, fontFace_1 = fontFace; _a < fontFace_1.length; _a++) {
        var face = fontFace_1[_a];
        freeStyle.registerRule('@font-face', face);
    }
    styleUpdated();
    return;
}
exports.fontFace = fontFace;
/**
 * Takes CSSProperties and registers it to a global selector (body, html, etc.)
 */
function cssRule(selector) {
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var object = formatting_1.ensureStringObj(extend.apply(void 0, objects)).result;
    freeStyle.registerRule(selector, object);
    styleUpdated();
    return;
}
exports.cssRule = cssRule;
/**
 * Takes Keyframes and returns a generated animation name
 */
function keyframes(frames) {
    // resolve keyframe css property helpers
    for (var key in frames) {
        var frame = frames[key];
        for (var prop in frame) {
            frame[prop] = formatting_1.ensureString(frame[prop]);
        }
    }
    var animationName = freeStyle.registerKeyframes(frames);
    styleUpdated();
    return animationName;
}
exports.keyframes = keyframes;
/**
 * Helper for you to create a CSSFunction
 * Assumption is that most css function fall into this pattern:
 * `function-name(param [, param])`
 */
function cssFunction(functionName) {
    var params = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        params[_i - 1] = arguments[_i];
    }
    var parts = params.map(formatting_1.ensureString).join(',');
    return functionName + "(" + parts + ")";
}
exports.cssFunction = cssFunction;
/**
 * Merges various styles into a single style object.
 * Note: if two objects have the same property the last one wins
 */
function extend() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    /** The final result we will return */
    var result = {};
    for (var _a = 0, objects_1 = objects; _a < objects_1.length; _a++) {
        var object = objects_1[_a];
        for (var key in object) {
            /** Falsy values except a explicit 0 is ignored */
            var val = object[key];
            if (!val && val !== 0) {
                continue;
            }
            /** if nested media or pseudo selector */
            if (key === '$nest' && val) {
                result[key] = result['$nest'] ? extend(result['$nest'], val) : val;
            }
            else if ((key.indexOf('&') !== -1 || key.indexOf('@media') === 0)) {
                result[key] = result[key] ? extend(result[key], val) : val;
            }
            else {
                result[key] = val;
            }
        }
    }
    return result;
}
exports.extend = extend;
/**
 * Utility to join classes conditionally
 */
function classes() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return classes.filter(function (c) { return !!c; }).join(' ');
}
exports.classes = classes;
/**
 * Helps customize styles with media queries
 */
exports.media = function (mediaQuery) {
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var mediaQuerySections = [];
    if (mediaQuery.type)
        mediaQuerySections.push(mediaQuery.type);
    if (mediaQuery.orientation)
        mediaQuerySections.push(mediaQuery.orientation);
    if (mediaQuery.minWidth)
        mediaQuerySections.push("(min-width: " + mediaQuery.minWidth + "px)");
    if (mediaQuery.maxWidth)
        mediaQuerySections.push("(max-width: " + mediaQuery.maxWidth + "px)");
    var stringMediaQuery = "@media " + mediaQuerySections.join(' and ');
    var object = {
        $nest: (_a = {},
            _a[stringMediaQuery] = extend.apply(void 0, objects),
            _a)
    };
    return object;
    var _a;
};

==> typestyle-0.17.0.tgz: package/lib/index.js <==
"use strict";
var formatting_1 = require("./internal/formatting");
/**
 * All the CSS types in the 'types' namespace
 */
exports.types = require("./types");
/**
 * @module Maintains a single stylesheet and keeps it in sync with requested styles
 */
var FreeStyle = require("free-style");
/** Raf for node + browser */
var raf = typeof requestAnimationFrame === 'undefined' ? setTimeout : requestAnimationFrame;
/**
 * Only calls cb all sync operations settle
 */
var afterAllSync = (new (function () {
    function class_1() {
        var _this = this;
        this.pending = 0;
        this.afterAllSync = function (cb) {
            _this.pending++;
            var pending = _this.pending;
            raf(function () {
                if (pending !== _this.pending)
                    return;
                cb();
            });
        };
    }
    return class_1;
}())).afterAllSync;
/**
 * We have a single stylesheet that we update as components register themselves
 */
var freeStyle = FreeStyle.create();
var lastFreeStyleChangeId = freeStyle.changeId;
/**
 * We create a tag on first request or return the one that was hydrated
 */
var _a = new (function () {
    function class_2() {
        var _this = this;
        this.singletonTag = undefined;
        this.getTag = function () {
            if (!_this.singletonTag) {
                _this.singletonTag = typeof window === 'undefined' ? { innerHTML: '' } : document.createElement('style');
                if (typeof document !== 'undefined')
                    document.head.appendChild(_this.singletonTag);
            }
            return _this.singletonTag;
        };
        this.setTag = function (tag) {
            /** Clear any data in any previous tag */
            if (_this.singletonTag) {
                _this.singletonTag.innerHTML = '';
            }
            _this.singletonTag = tag;
            /** This special time buffer immediately */
            forceRenderStyles();
        };
    }
    return class_2;
}()), setTag = _a.setTag, getTag = _a.getTag;
/** Sets the target tag where we write the css on style updates */
exports.setStylesTarget = setTag;
/** Checks if the style tag needs updating and if so queues up the change */
var styleUpdated = function () {
    if (freeStyle.changeId === lastFreeStyleChangeId
        && !pendingRawChange)
        return;
    lastFreeStyleChangeId = freeStyle.changeId;
    pendingRawChange = false;
    afterAllSync(forceRenderStyles);
};
var pendingRawChange = false;
var raw = '';
/**
 * Insert `raw` CSS as a string. This is useful for e.g.
 * - third party CSS that you are customizing with template strings
 * - generating raw CSS in JavaScript
 * - reset libraries like normalize.css that you can use without loaders
 */
function cssRaw(mustBeValidCSS) {
    if (!mustBeValidCSS)
        return;
    raw = raw + mustBeValidCSS;
    pendingRawChange = true;
    styleUpdated();
}
exports.cssRaw = cssRaw;
/**
 * Renders styles to the singleton tag imediately
 * NOTE: You should only call it on initial render to prevent any non CSS flash.
 * After that it is kept sync using `requestAnimationFrame` and we haven't noticed any bad flashes.
 **/
function forceRenderStyles() {
    getTag().innerHTML = exports.getCss();
}
exports.forceRenderStyles = forceRenderStyles;
/**
 * Helps with testing. Reinitializes FreeStyle + raw
 */
function reinit() {
    /** reinit freestyle */
    freeStyle = FreeStyle.create();
    lastFreeStyleChangeId = freeStyle.changeId;
    /** reinit raw */
    raw = '';
    pendingRawChange = false;
    /** Clear any styles that were flushed */
    getTag().innerHTML = '';
}
exports.reinit = reinit;
/**
 * Allows use to use the stylesheet in a node.js environment
 */
exports.getCss = function () { return raw ? raw + freeStyle.getStyles() : freeStyle.getStyles(); };
/**
 * Takes CSSProperties and return a generated className you can use on your component
 */
function style() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    var _a = formatting_1.ensureStringObj(extend.apply(void 0, objects)), result = _a.result, debugName = _a.debugName;
    var className = debugName ? freeStyle.registerStyle(result, debugName) : freeStyle.registerStyle(result);
    styleUpdated();
    return className;
}
exports.style = style;
function fontFace() {
    var fontFace = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        fontFace[_i] = arguments[_i];
    }
    for (var _a = 0, fontFace_1 = fontFace; _a < fontFace_1.length; _a++) {
        var face = fontFace_1[_a];
        freeStyle.registerRule('@font-face', face);
    }
    styleUpdated();
    return;
}
exports.fontFace = fontFace;
/**
 * Takes CSSProperties and registers it to a global selector (body, html, etc.)
 */
function cssRule(selector) {
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var object = formatting_1.ensureStringObj(extend.apply(void 0, objects)).result;
    freeStyle.registerRule(selector, object);
    styleUpdated();
    return;
}
exports.cssRule = cssRule;
/**
 * Takes Keyframes and returns a generated animation name
 */
function keyframes(frames) {
    // resolve keyframe css property helpers
    for (var key in frames) {
        var frame = frames[key];
        for (var prop in frame) {
            frame[prop] = formatting_1.ensureString(frame[prop]);
        }
    }
    var animationName = freeStyle.registerKeyframes(frames);
    styleUpdated();
    return animationName;
}
exports.keyframes = keyframes;
/**
 * Helper for you to create a CSSFunction
 * Assumption is that most css function fall into this pattern:
 * `function-name(param [, param])`
 */
function cssFunction(functionName) {
    var params = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        params[_i - 1] = arguments[_i];
    }
    var parts = params.map(formatting_1.ensureString).join(',');
    return functionName + "(" + parts + ")";
}
exports.cssFunction = cssFunction;
/**
 * Merges various styles into a single style object.
 * Note: if two objects have the same property the last one wins
 */
function extend() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    /** The final result we will return */
    var result = {};
    for (var _a = 0, objects_1 = objects; _a < objects_1.length; _a++) {
        var object = objects_1[_a];
        for (var key in object) {
            /** Falsy values except a explicit 0 is ignored */
            var val = object[key];
            if (!val && val !== 0) {
                continue;
            }
            /** if nested media or pseudo selector */
            if (key === '$nest' && val) {
                result[key] = result['$nest'] ? extend(result['$nest'], val) : val;
            }
            else if ((key.indexOf('&') !== -1 || key.indexOf('@media') === 0)) {
                result[key] = result[key] ? extend(result[key], val) : val;
            }
            else {
                result[key] = val;
            }
        }
    }
    return result;
}
exports.extend = extend;
/**
 * Utility to join classes conditionally
 */
function classes() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return classes.filter(function (c) { return !!c; }).join(' ');
}
exports.classes = classes;
/**
 * Helps customize styles with media queries
 */
exports.media = function (mediaQuery) {
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var mediaQuerySections = [];
    if (mediaQuery.type)
        mediaQuerySections.push(mediaQuery.type);
    if (mediaQuery.orientation)
        mediaQuerySections.push(mediaQuery.orientation);
    if (mediaQuery.minWidth)
        mediaQuerySections.push("(min-width: " + mediaQuery.minWidth + "px)");
    if (mediaQuery.maxWidth)
        mediaQuerySections.push("(max-width: " + mediaQuery.maxWidth + "px)");
    var stringMediaQuery = "@media " + mediaQuerySections.join(' and ');
    var object = {
        $nest: (_a = {},
            _a[stringMediaQuery] = extend.apply(void 0, objects),
            _a)
    };
    return object;
    var _a;
};
